@@ -1,5 +1,6 @@
 import io
 import json
+from os import walk
 import re
 import time
 import traceback
@@ -9,6 +10,7 @@ from contextlib import redirect_stdout, redirect_stderr
 from datetime import datetime
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
+from orionis.app import Orionis
 from orionis.container.resolver.resolver import Resolver
 from orionis.foundation.config.testing.enums.drivers import PersistentDrivers
 from orionis.foundation.config.testing.enums.mode import ExecutionMode
@@ -19,30 +21,10 @@ from orionis.test.contracts.test_result import IOrionisTestResult
 from orionis.test.contracts.unit_test import IUnitTest
 from orionis.test.entities.result import TestResult
 from orionis.test.enums import TestStatus
-from orionis.test.exceptions import (
-    OrionisTestFailureException,
-    OrionisTestPersistenceError,
-    OrionisTestValueError,
-)
+from orionis.test.exceptions import *
 from orionis.test.output.printer import TestPrinter
 from orionis.test.records.logs import TestLogs
-from orionis.test.validators import (
-    ValidExecutionMode,
-    ValidFailFast,
-    ValidPersistent,
-    ValidPersistentDriver,
-    ValidPrintResult,
-    ValidThrowException,
-    ValidVerbosity,
-    ValidWebReport,
-    ValidWorkers,
-    ValidBasePath,
-    ValidFolderPath,
-    ValidNamePattern,
-    ValidPattern,
-    ValidTags,
-    ValidModuleName,
-)
+from orionis.test.validators import *
 from orionis.test.view.render import TestingResultRender
 
 class UnitTest(IUnitTest):
@@ -52,57 +34,11 @@ class UnitTest(IUnitTest):
     Advanced unit testing manager for the Orionis framework.
 
     This class provides mechanisms for discovering, executing, and reporting unit tests with extensive configurability. It supports sequential and parallel execution, test filtering by name or tags, and detailed result tracking including execution times, error messages, and tracebacks.
-
-    Attributes
-    ----------
-    __app : Optional[IApplication]
-        Application instance for dependency injection.
-    __verbosity : Optional[int]
-        Verbosity level for test output.
-    __execution_mode : Optional[str]
-        Execution mode for tests ('SEQUENTIAL' or 'PARALLEL').
-    __max_workers : Optional[int]
-        Maximum number of workers for parallel execution.
-    __fail_fast : Optional[bool]
-        Whether to stop on first failure.
-    __throw_exception : Optional[bool]
-        Whether to raise exceptions on test failures.
-    __persistent : Optional[bool]
-        Whether to persist test results.
-    __persistent_driver : Optional[str]
-        Persistence driver ('sqlite' or 'json').
-    __web_report : Optional[bool]
-        Whether to generate a web report.
-    __folder_path : Optional[str]
-        Folder path for test discovery.
-    __base_path : Optional[str]
-        Base directory for test discovery.
-    __pattern : Optional[str]
-        File name pattern for test discovery.
-    __test_name_pattern : Optional[str]
-        Pattern for filtering test names.
-    __tags : Optional[List[str]]
-        Tags for filtering tests.
-    __module_name : Optional[str]
-        Module name for test discovery.
-    __loader : unittest.TestLoader
-        Loader for discovering tests.
-    __suite : unittest.TestSuite
-        Test suite containing discovered tests.
-    __discovered_tests : List
-        List of discovered test metadata.
-    __printer : Optional[TestPrinter]
-        Utility for printing test results.
-    __output_buffer : Optional[str]
-        Buffer for capturing standard output.
-    __error_buffer : Optional[str]
-        Buffer for capturing error output.
-    __result : Optional[dict]
-        Result summary of the test execution.
     """
 
     def __init__(
-        self
+        self,
+        app: Optional[IApplication] = None
     ) -> None:
         """
         Initialize a UnitTest instance with default configuration and internal state.
@@ -113,11 +49,12 @@ class UnitTest(IUnitTest):
         -------
         None
         """
-        # Application instance for dependency injection (set via __setApp)
-        self.__app: Optional[IApplication] = None
 
-        # Storage path for test results (set via __setApp)
-        self.__storage: Optional[str] = None
+        # Application instance for dependency injection
+        self.__app: Optional[IApplication] = app or Orionis()
+
+        # Storage path for test results
+        self.__storage: Optional[str] = self.__app.path('storage_testing')
 
         # Configuration values (set via configure)
         self.__verbosity: Optional[int] = None
@@ -220,6 +157,100 @@ class UnitTest(IUnitTest):
         # Return the instance to allow method chaining
         return self
 
+    def discoverTests(
+        self,
+        base_path: str | Path,
+        folder_path: str | List[str],
+        pattern: str,
+        test_name_pattern: Optional[str] = None,
+        tags: Optional[List[str]] = None
+    ) -> 'UnitTest':
+        """
+        Discover test cases from specified folders using flexible path discovery.
+
+        This method provides a convenient way to discover and load test cases from multiple folders
+        based on various path specifications. It supports wildcard discovery, single folder loading,
+        and multiple folder loading. The method automatically resolves paths relative to the base
+        directory and discovers all folders containing files matching the specified pattern.
+
+        Parameters
+        ----------
+        base_path : str or Path
+            Base directory path for resolving relative folder paths. This serves as the root
+            directory from which all folder searches are conducted.
+        folder_path : str or list of str
+            Specification of folders to search for test cases. Can be:
+            - '*' : Discover all folders containing matching files within base_path
+            - str : Single folder path relative to base_path
+            - list of str : Multiple folder paths relative to base_path
+        pattern : str
+            File name pattern to match test files, supporting wildcards (* and ?).
+            Examples: 'test_*.py', '*_test.py', 'test*.py'
+        test_name_pattern : str, optional
+            Regular expression pattern to filter test method names. Only tests whose
+            names match this pattern will be included. Default is None (no filtering).
+        tags : list of str, optional
+            List of tags to filter tests. Only tests decorated with matching tags
+            will be included. Default is None (no tag filtering).
+
+        Returns
+        -------
+        UnitTest
+            The current UnitTest instance with discovered tests added to the suite,
+            enabling method chaining.
+
+        Notes
+        -----
+        - All paths are resolved as absolute paths relative to the base_path
+        - When folder_path is '*', the method searches recursively through all subdirectories
+        - The method uses the existing discoverTestsInFolder method for actual test discovery
+        - Duplicate folders are automatically eliminated using a set data structure
+        - The method does not validate the existence of specified folders; validation
+          occurs during the actual test discovery process
+        """
+        # Resolve the base path as an absolute path from the current working directory
+        base_path = (Path.cwd() / base_path).resolve()
+
+        # Use a set to store discovered folders and automatically eliminate duplicates
+        discovered_folders = set()
+
+        # Handle wildcard discovery: search all folders containing matching files
+        if folder_path == '*':
+
+            # Search recursively through the entire base path for folders with matching files
+            discovered_folders.update(self.__listMatchingFolders(base_path, base_path, pattern))
+
+        # Handle multiple folder paths: process each folder in the provided list
+        elif isinstance(folder_path, list):
+            for custom in folder_path:
+                # Resolve each custom folder path relative to the base path
+                custom_path = (base_path / custom).resolve()
+                # Add all matching folders found within this custom path
+                discovered_folders.update(self.__listMatchingFolders(base_path, custom_path, pattern))
+
+        # Handle single folder path: process the single specified folder
+        else:
+
+            # Resolve the single folder path relative to the base path
+            custom_path = (base_path / folder_path).resolve()
+            # Add all matching folders found within this single path
+            discovered_folders.update(self.__listMatchingFolders(base_path, custom_path, pattern))
+
+        # Iterate through all discovered folders and perform test discovery
+        for folder in discovered_folders:
+
+            # Use the existing discoverTestsInFolder method to actually discover and load tests
+            self.discoverTestsInFolder(
+                base_path=base_path,
+                folder_path=folder,
+                pattern=pattern,
+                test_name_pattern=test_name_pattern or None,
+                tags=tags or None
+            )
+
+        # Return the current instance to enable method chaining
+        return self
+
     def discoverTestsInFolder(
         self,
         *,
@@ -1342,6 +1373,37 @@ class UnitTest(IUnitTest):
         # Return the suite containing only the filtered tests
         return filtered_suite
 
+    def __listMatchingFolders(
+        self,
+        base_path: Path,
+        custom_path: Path,
+        pattern: str
+    ) -> List[str]:
+        """
+        List folders within a given path containing files matching a pattern.
+
+        Parameters
+        ----------
+        base_path : Path
+            The base directory path for calculating relative paths.
+        custom_path : Path
+            The directory path to search for matching files.
+        pattern : str
+            The filename pattern to match, supporting '*' and '?' wildcards.
+
+        Returns
+        -------
+        List[str]
+            List of relative folder paths containing files matching the pattern.
+        """
+        regex = re.compile('^' + pattern.replace('*', '.*').replace('?', '.') + '$')
+        matched_folders = set()
+        for root, _, files in walk(str(custom_path)):
+            if any(regex.fullmatch(file) for file in files):
+                rel_path = Path(root).relative_to(base_path).as_posix()
+                matched_folders.add(rel_path)
+        return list(matched_folders)
+
     def getTestNames(
         self
     ) -> List[str]:
