@@ -4,28 +4,23 @@ class __ValidPrintResult:
 
     def __call__(self, print_result) -> bool:
         """
-        Validator that ensures the `print_result` parameter is a boolean.
-
-        This class is intended to be used as a callable validator to check that the
-        provided `print_result` argument is of type `bool`. If the validation fails,
-        an `OrionisTestValueError` is raised.
+        Validates that the `print_result` parameter is a boolean.
 
         Parameters
         ----------
         print_result : Any
-            The value to be validated as a boolean.
+            The value to validate as a boolean.
 
         Returns
         -------
         bool
-            Returns the validated boolean value of `print_result`.
+            The validated boolean value of `print_result`.
 
         Raises
         ------
         OrionisTestValueError
             If `print_result` is not of type `bool`.
         """
-
         if not isinstance(print_result, bool):
             raise OrionisTestValueError(
                 f"Invalid print_result: Expected a boolean, got '{print_result}' ({type(print_result).__name__})."
@@ -34,4 +29,4 @@ class __ValidPrintResult:
         return print_result
 
 # Exported singleton instance
-ValidPrintResult = __ValidPrintResult()
+ValidPrintResult = __ValidPrintResult()
\ No newline at end of file
